@@ -108,11 +108,6 @@ struct s2n_array *cbmc_allocate_s2n_array()
     return array;
 }
 
-bool s2n_set_is_bounded(const struct s2n_set *set, const size_t max_len, const size_t max_element_size)
-{
-    return s2n_array_is_bounded(set->data, max_len, max_element_size);
-}
-
 static int nondet_comparator(const void *a, const void *b)
 {
     __CPROVER_assert(a != NULL, "a is not NULL");
@@ -120,20 +115,6 @@ static int nondet_comparator(const void *a, const void *b)
     return nondet_int();
 }
 
-void cbmc_populate_s2n_set(struct s2n_set *set)
-{
-    CBMC_ENSURE_REF(set);
-    set->data       = cbmc_allocate_s2n_array();
-    set->comparator = nondet_comparator;
-}
-
-struct s2n_set *cbmc_allocate_s2n_set()
-{
-    struct s2n_set *set = malloc(sizeof(*set));
-    cbmc_populate_s2n_set(set);
-    return set;
-}
-
 void cbmc_populate_s2n_dh_params(struct s2n_dh_params *s2n_dh_params)
 {
     CBMC_ENSURE_REF(s2n_dh_params);
@@ -413,7 +394,6 @@ void cbmc_populate_s2n_pkey(struct s2n_pkey *s2n_pkey)
      * `s2n_pkey->verify`
      * `s2n_pkey->encrypt`
      * `s2n_pkey->decrypt`
-     * `s2n_pkey->match`
      * `s2n_pkey->free`
      * `s2n_pkey->check_key` are never allocated.
      * If required, these initializations should be done in the proof harness.
