@@ -261,6 +261,7 @@ int main(int argc, char **argv)
             }
 
             EXPECT_NOT_NULL(client_config = s2n_config_new());
+            EXPECT_SUCCESS(s2n_config_set_cipher_preferences(client_config, "20170210"));
             EXPECT_SUCCESS(s2n_config_set_unsafe_for_testing(client_config));
 
             EXPECT_SUCCESS(s2n_config_set_verification_ca_location(client_config, S2N_DEFAULT_TEST_CERT_CHAIN, NULL));
@@ -457,7 +458,7 @@ int main(int argc, char **argv)
 
                 DEFER_CLEANUP(struct s2n_config *config = s2n_config_new(), s2n_config_ptr_free);
                 EXPECT_NOT_NULL(config);
-                EXPECT_SUCCESS(s2n_config_set_cipher_preferences(config, "default"));
+                EXPECT_SUCCESS(s2n_config_set_cipher_preferences(config, "20170210"));
                 EXPECT_SUCCESS(s2n_config_add_cert_chain_and_key_to_store(config, chain_and_key));
                 EXPECT_SUCCESS(s2n_config_set_verification_ca_location(config, S2N_DEFAULT_TEST_CERT_CHAIN, NULL));
                 EXPECT_SUCCESS(s2n_config_disable_x509_verification(config));
@@ -474,5 +475,4 @@ int main(int argc, char **argv)
     }
 
     END_TEST();
-    return 0;
 }
