@@ -243,6 +243,16 @@ int s2n_test_tls13_pq_handshake(const struct s2n_security_policy *client_sec_pol
         POSIX_ENSURE_EQ(memcmp(expected_kem_group->name, s2n_connection_get_kem_group_name(server_conn), strlen(expected_kem_group->name)), 0);
         POSIX_ENSURE_EQ(strlen(expected_kem_group->name), strlen(s2n_connection_get_kem_group_name(client_conn)));
         POSIX_ENSURE_EQ(memcmp(expected_kem_group->name, s2n_connection_get_kem_group_name(client_conn), strlen(expected_kem_group->name)), 0);
+
+        /* Ensure s2n_connection_get_key_exchange_group() gives the correct answer for both client and server */
+        const char *server_group_name = NULL;
+        const char *client_group_name = NULL;
+        POSIX_GUARD(s2n_connection_get_key_exchange_group(server_conn, &server_group_name));
+        POSIX_GUARD(s2n_connection_get_key_exchange_group(client_conn, &client_group_name));
+        POSIX_ENSURE_EQ(strlen(expected_kem_group->name), strlen(server_group_name));
+        POSIX_ENSURE_EQ(memcmp(expected_kem_group->name, server_group_name, strlen(expected_kem_group->name)), 0);
+        POSIX_ENSURE_EQ(strlen(expected_kem_group->name), strlen(client_group_name));
+        POSIX_ENSURE_EQ(memcmp(expected_kem_group->name, client_group_name, strlen(expected_kem_group->name)), 0);
     } else {
         POSIX_ENSURE_EQ(NULL, client_conn->kex_params.server_kem_group_params.kem_group);
         POSIX_ENSURE_EQ(NULL, client_conn->kex_params.server_kem_group_params.kem_params.kem);
@@ -259,6 +269,16 @@ int s2n_test_tls13_pq_handshake(const struct s2n_security_policy *client_sec_pol
         POSIX_ENSURE_EQ(memcmp(expected_curve->name, s2n_connection_get_curve(server_conn), strlen(expected_curve->name)), 0);
         POSIX_ENSURE_EQ(strlen(expected_curve->name), strlen(s2n_connection_get_curve(client_conn)));
         POSIX_ENSURE_EQ(memcmp(expected_curve->name, s2n_connection_get_curve(client_conn), strlen(expected_curve->name)), 0);
+
+        /* Ensure s2n_connection_get_key_exchange_group() gives the correct answer for both client and server */
+        const char *server_group_name = NULL;
+        const char *client_group_name = NULL;
+        POSIX_GUARD(s2n_connection_get_key_exchange_group(server_conn, &server_group_name));
+        POSIX_GUARD(s2n_connection_get_key_exchange_group(client_conn, &client_group_name));
+        POSIX_ENSURE_EQ(strlen(expected_curve->name), strlen(server_group_name));
+        POSIX_ENSURE_EQ(memcmp(expected_curve->name, server_group_name, strlen(expected_curve->name)), 0);
+        POSIX_ENSURE_EQ(strlen(expected_curve->name), strlen(client_group_name));
+        POSIX_ENSURE_EQ(memcmp(expected_curve->name, client_group_name, strlen(expected_curve->name)), 0);
     }
 
     /* Verify basic properties of secrets */
@@ -406,6 +426,27 @@ int main()
         .ecc_preferences = &s2n_ecc_preferences_20201021,
     };
 
+    const struct s2n_kem_group *mlkem768_test_groups[] = {
+        &s2n_x25519_mlkem_768,
+        &s2n_secp256r1_mlkem_768,
+    };
+
+    const struct s2n_kem_preferences mlkem768_test_prefs = {
+        .kem_count = 0,
+        .kems = NULL,
+        .tls13_kem_group_count = s2n_array_len(mlkem768_test_groups),
+        .tls13_kem_groups = mlkem768_test_groups,
+        .tls13_pq_hybrid_draft_revision = 5
+    };
+
+    const struct s2n_security_policy mlkem768_test_policy = {
+        .minimum_protocol_version = S2N_TLS13,
+        .cipher_preferences = &cipher_preferences_20190801,
+        .kem_preferences = &mlkem768_test_prefs,
+        .signature_preferences = &s2n_signature_preferences_20200207,
+        .ecc_preferences = &s2n_ecc_preferences_20240603,
+    };
+
     const struct s2n_security_policy ecc_retry_policy = {
         .minimum_protocol_version = security_policy_pq_tls_1_0_2020_12.minimum_protocol_version,
         .cipher_preferences = security_policy_pq_tls_1_0_2020_12.cipher_preferences,
@@ -429,6 +470,52 @@ int main()
         bool len_prefix_expected;
     };
 
+    /* Self talk test with each TLS 1.3 KemGroup we support */
+    for (size_t i = 0; i < S2N_KEM_GROUPS_COUNT; i++) {
+        const struct s2n_kem_group *kem_group = ALL_SUPPORTED_KEM_GROUPS[i];
+
+        if (kem_group == NULL || !s2n_kem_group_is_available(kem_group)) {
+            continue;
+        }
+
+        const struct s2n_kem_preferences singleton_test_pref = {
+            .kem_count = 0,
+            .kems = NULL,
+            .tls13_kem_group_count = 1,
+            .tls13_kem_groups = &kem_group,
+            .tls13_pq_hybrid_draft_revision = 5
+        };
+
+        const struct s2n_security_policy singleton_test_policy = {
+            .minimum_protocol_version = S2N_TLS13,
+            .cipher_preferences = &cipher_preferences_20190801,
+            .kem_preferences = &singleton_test_pref,
+            .signature_preferences = &s2n_signature_preferences_20200207,
+            .ecc_preferences = &s2n_ecc_preferences_20240603,
+        };
+
+        const struct pq_handshake_test_vector test_vec = {
+            .client_policy = &singleton_test_policy,
+            .server_policy = &singleton_test_policy,
+            .expected_kem_group = kem_group,
+            .expected_curve = NULL,
+            .hrr_expected = false,
+            .len_prefix_expected = false,
+        };
+
+        EXPECT_SUCCESS(s2n_test_tls13_pq_handshake(test_vec.client_policy, test_vec.server_policy,
+                test_vec.expected_kem_group, test_vec.expected_curve, test_vec.hrr_expected, test_vec.len_prefix_expected));
+    }
+
+    /* ML-KEM is only available on newer versions of AWS-LC. If it's
+     * unavailable, we must downgrade the assertions to Kyber or EC. */
+    const struct s2n_kem_group *null_if_no_mlkem = &s2n_x25519_mlkem_768;
+    const struct s2n_ecc_named_curve *ec_if_no_mlkem = NULL;
+    if (!s2n_libcrypto_supports_mlkem()) {
+        null_if_no_mlkem = NULL;
+        ec_if_no_mlkem = default_curve;
+    }
+
     /* Test vectors that expect to negotiate PQ assume that PQ is enabled in s2n.
      * If PQ is disabled, the expected negotiation outcome is overridden below
      * before performing the handshake test. */
@@ -642,6 +729,16 @@ int main()
                 .hrr_expected = true,
                 .len_prefix_expected = true,
         },
+
+        /* Confirm that MLKEM768 is negotiable */
+        {
+                .client_policy = &mlkem768_test_policy,
+                .server_policy = &mlkem768_test_policy,
+                .expected_kem_group = null_if_no_mlkem,
+                .expected_curve = ec_if_no_mlkem,
+                .hrr_expected = false,
+                .len_prefix_expected = false,
+        }
     };
 
     for (size_t i = 0; i < s2n_array_len(test_vectors); i++) {
